@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2018 Canonical
+ * Copyright (C) 2014-2019 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -817,7 +817,6 @@ static void stats_print(
 	const stats_t *const s)
 {
 	char buf[10], bogo_ops[10];
-	char cpu_cycles[10], cpu_instr[10];
 	char *fmt;
 
 	if (summary) {
@@ -833,13 +832,12 @@ static void stats_print(
 	value_to_str(s->value[BOGO_OPS], s->inaccurate[BOGO_OPS],
 		bogo_ops, sizeof(bogo_ops));
 	if (perf_enabled) {
+		char cpu_cycles[10], cpu_instr[10];
+
 		value_to_str(s->value[CPU_CYCLES], s->inaccurate[CPU_CYCLES],
 			cpu_cycles, sizeof(cpu_cycles));
 		value_to_str(s->value[CPU_INSTRUCTIONS], s->inaccurate[CPU_INSTRUCTIONS],
 			cpu_instr, sizeof(cpu_instr));
-	}
-
-	if (perf_enabled) {
 		fmt = summary ?
 			"%10.10s %5.1f %5.1f %5.1f %4.1f %7.1f %6.1f %6s %6s %6s %s\n" :
 			"%10.10s %5.1f %5.1f %5.1f %4.0f %7.0f %6.0f %6s %6s %6s %s\n";
@@ -1834,7 +1832,7 @@ static int monitor_cpu_load(
 			double percent_each = 100.0 / (samples_cpu * num_cpus);
 			double percent = n * percent_each;
 
-			(void)snprintf(buffer, sizeof(buffer), "%d%% x %d",
+			(void)snprintf(buffer, sizeof(buffer), "%d%% x %u",
 				cpu_load, n_cpus);
 			start_load(cpu_list, n_cpus, stress_cpu,
 				(uint64_t)cpu_load, bogo_ops);
@@ -1874,7 +1872,7 @@ static int monitor_cpu_load(
 		}
 	}
 	/* Keep static analysis happy */
-	if (n <= 0) {
+	if (n == 0) {
 		printf("\nZero samples, cannot compute statistics.\n");
 		return -1;
 	}
@@ -1906,7 +1904,7 @@ static int monitor_cpu_load(
 			}
 		}
 	} else {
-		(void)printf("\nFor %d CPU%s (of a %d CPU system):\n",
+		(void)printf("\nFor %u CPU%s (of a %d CPU system):\n",
 			cpu_list->count, cpu_list->count > 1 ? "s" : "", max_cpus);
 		show_trend(fp, CPU_ANY, values_load, n,
 			"% CPU load", "1% CPU load",
